==> agrosyst-cli-1.4.6-sources.jar: fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java <==
package fr.inra.agrosyst.services.pz0import.action.seedingActionSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: SeedingActionSpeciesImportDto.java 4796 2015-02-17 06:42:30Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/1.4.6/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.action.HarvestingYealdAbstract;
import fr.inra.agrosyst.api.entities.action.SeedPlantUnit;
import fr.inra.agrosyst.api.entities.action.SeedingActionSpeciesAbstract;
import fr.inra.agrosyst.api.entities.action.YealdCategory;
import fr.inra.agrosyst.api.entities.action.YealdUnit;

/**
 * Created by davidcosse on 12/02/15.
 */
public class SeedingActionSpeciesImportDto extends SeedingActionSpeciesAbstract {

    protected String id;

    protected Double quantityWithNull;

    protected String seedPlantUnitName;

    protected String seedingActionId;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Double getQuantityWithNull() {
        return quantityWithNull;
    }

    public void setQuantityWithNull(Double quantityWithNull) {
        this.quantityWithNull = quantityWithNull;
    }

    public String getSeedPlantUnitName() {
        return seedPlantUnitName;
    }

    public void setSeedPlantUnitName(String seedPlantUnitName) {
        this.seedPlantUnitName = seedPlantUnitName;
    }

    public String getSeedingActionId() {
        return seedingActionId;
    }

    public void setSeedingActionId(String seedingActionId) {
        this.seedingActionId = seedingActionId;
    }
}

==> agrosyst-cli-1.4.7-sources.jar: fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java <==
package fr.inra.agrosyst.services.pz0import.action.seedingActionSpecies;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: SeedingActionSpeciesImportDto.java 4796 2015-02-17 06:42:30Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.7/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/seedingActionSpecies/SeedingActionSpeciesImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import fr.inra.agrosyst.api.entities.action.HarvestingYealdAbstract;
import fr.inra.agrosyst.api.entities.action.SeedPlantUnit;
import fr.inra.agrosyst.api.entities.action.SeedingActionSpeciesAbstract;
import fr.inra.agrosyst.api.entities.action.YealdCategory;
import fr.inra.agrosyst.api.entities.action.YealdUnit;

/**
 * Created by davidcosse on 12/02/15.
 */
public class SeedingActionSpeciesImportDto extends SeedingActionSpeciesAbstract {

    protected String id;

    protected Double quantityWithNull;

    protected String seedPlantUnitName;

    protected String seedingActionId;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Double getQuantityWithNull() {
        return quantityWithNull;
    }

    public void setQuantityWithNull(Double quantityWithNull) {
        this.quantityWithNull = quantityWithNull;
    }

    public String getSeedPlantUnitName() {
        return seedPlantUnitName;
    }

    public void setSeedPlantUnitName(String seedPlantUnitName) {
        this.seedPlantUnitName = seedPlantUnitName;
    }

    public String getSeedingActionId() {
        return seedingActionId;
    }

    public void setSeedingActionId(String seedingActionId) {
        this.seedingActionId = seedingActionId;
    }
}
